# Fantasy LCS API Wrapper

Created a Fantasy LCS API in Python 3.6.

# Installation

Run the following command in your terminal from the source:

```pip install fantasylcs```

# Documentation

### Table of Contents:
* [FantasyLeague documentation](https://github.com/kodycode/Fantasy-LCS-API-Wrapper/wiki/FantasyLeague)
    * Obtains general data from the specified fantasy league
* [SeasonData documentation](https://github.com/kodycode/Fantasy-LCS-API-Wrapper/wiki/SeasonData)
    * Obtains data of the fantasy season so far
* [PlayerData documentation](https://github.com/kodycode/Fantasy-LCS-API-Wrapper/wiki/PlayerData)
    * Obtains the player's seasonal data
* [TeamData documentation](https://github.com/kodycode/Fantasy-LCS-API-Wrapper/wiki/TeamData)
    * Obtains the team's seasonal data


# Donations

Boost this summoner out?

[![paypal](https://www.paypalobjects.com/en_US/i/btn/btn_donate_SM.gif)](https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=XVWUDA7TZH2SU)
